@@ -1,7 +1,7 @@
 package Tree::ToTextLines;
 
-our $DATE = '2016-11-21'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-11-23'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -88,9 +88,9 @@ sub _render_node {
     }
     $res .= "$node_res\n";
 
-    my $children_method = $opts->{children_method} // 'children';
+    my $get_children_method = $opts->{get_children_method} // 'children';
 
-    my @children = $node->$children_method;
+    my @children = $node->$get_children_method;
     @children = () unless defined($children[0]);
     @children = @{$children[0]} if @children==1 && ref($children[0]) eq 'ARRAY';
     my @children_res;
@@ -143,7 +143,7 @@ Tree::ToTextLines - Render a tree object as indented text lines
 
 =head1 VERSION
 
-This document describes version 0.04 of Tree::ToTextLines (from Perl distribution Tree-ToText), released on 2016-11-21.
+This document describes version 0.05 of Tree::ToTextLines (from Perl distribution Tree-ToText), released on 2016-11-23.
 
 =head1 SYNOPSIS
 
@@ -217,7 +217,7 @@ child node will be indented more deeply than its parent node.
 Tree object of any kind of class is accepted as long as the class responds to
 C<children> and the method returns a list or arrayref of children nodes. The
 name of the children method C<children> can be customized using
-C<children_method> option.
+C<get_children_method> option.
 
 This function is the complement for C<build_tree_from_text_lines> function in
 L<Tree::FromTextLines>.
@@ -265,11 +265,11 @@ Available options:
 
 =over
 
-=item * children_method => str (default: children)
+=item * get_children_method => str (default: children)
 
 Example:
 
- children_method => "get_children"
+ get_children_method => "get_children"
 
 By default, C<children> is the method that will be used on node objects to
 retrieve children nodes. But you can customize that using this option. Note that
